#######
*QUIMB*
#######

.. image:: https://img.shields.io/travis/jcmgray/quimb/develop.svg
    :target: https://travis-ci.org/jcmgray/quimb
.. image:: https://img.shields.io/codecov/c/github/jcmgray/quimb/develop.svg
  :target: https://codecov.io/gh/jcmgray/quimb
.. image:: https://api.codacy.com/project/badge/Grade/490e11dea3984e25aae1f915865f2c3f
   :target: https://www.codacy.com/app/jcmgray/quimb?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=jcmgray/quimb&amp;utm_campaign=Badge_Grade
.. image:: https://landscape.io/github/jcmgray/quimb/develop/landscape.svg?style=flat
   :target: https://landscape.io/github/jcmgray/quimb/develop
   :alt: Code Health
.. image:: https://img.shields.io/readthedocs/pip/latest.svg
   :target: http://quimb.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

* Python library for quantum information and many-body calcuations.
* Uses `numpy` and `scipy.sparse` matrices as quantum objects.
* Many operations accelerated using `numba` and `numexpr`.
* Optional `slepc4py` interface for easy distributed linear algebra.
* Simple tensor network manipulations and algorithms - (DMRG and DMRGX).

Documentation at: `<http://quimb.readthedocs.io/en/latest/>`_.
